@@ -47,7 +47,7 @@ var setWhitelist = function () {
 
         if (str !== '') {
             whitelist.push(
-                new RegExp('^https?:\/\/(www\.)?' + str + '/', 'i'));
+                new RegExp('^https?:\/\/(www\\.)?' + str + '/', 'i'));
         }
     }
 };
