@@ -62,7 +62,7 @@ var attributeHelpers = require("html_script_finder/dom_handler/attributes");
 var jsInAttrRe = attributeHelpers.jsInAttrRe;
 
 // the list of all available event attributes
-var intrinsecEvents = attributeHelpers.intrinsecEvents;
+var intrinsicEvents = attributeHelpers.intrinsicEvents;
 
 var domGatherer =
     require("html_script_finder/dom_handler/dom_gatherer").domGatherer;
@@ -101,10 +101,10 @@ var DomHandler = function() {
 
     // all scripts.
     this.scripts = [];
-    
+
     // keeps track of the number of scripts.
     this.numScripts = 0;
-    
+
     // store the reference to the callback method
     // presumably from htmlParser.
     this.callback = function() {};
@@ -131,7 +131,7 @@ var DomHandler = function() {
     // boolean to check if scripts were removed
     // prevents removeAllJs from running multiple times.
     this.removedAllScripts = null;
-    
+
     // will eventually contain an array of data
     // for the js web labels licenses.
     this.licenseList = [];
@@ -141,7 +141,7 @@ var DomHandler = function() {
 
     // number of scripts fully tested.
     this.scriptsTested = 0;
-    
+
     // number of external scripts to be tested.
     this.numExternalScripts = null;
 
@@ -150,7 +150,7 @@ var DomHandler = function() {
 };
 
 /**
- * Initialize properties of the object 
+ * Initialize properties of the object
  *
  * @param {domObject} obj A reference of the DOM object being
  * analyzed.
@@ -183,10 +183,10 @@ DomHandler.prototype.init = function(
 
     // make callback function available
     // for the entire object.
-    this.callback = function (dom) { 
+    this.callback = function (dom) {
         callback(dom);
         that.destroy();
-    }; 
+    };
 };
 
 DomHandler.prototype.reset = function () {
@@ -241,18 +241,20 @@ DomHandler.prototype.scriptHasJsWebLabel = function(script) {
     if (this.licenseList) {
 
         var url = urlHandler.resolve(this.pageURL, script.src),
-        i = 0, 
-        len = this.licenseList.length;
+            i = 0,
+            len = this.licenseList.length;
 
         console.debug('looking for web label');
 
         for (; i < len; i++) {
             if (this.licenseList[i].fileUrl === url &&
-                    this.licenseList[i].free === true) {
-                        console.debug('found something true');
-                        console.debug(this.licenseList[i].fileUrl, ' is found');
-                        return true;
-                    }
+                this.licenseList[i].free === true
+               ) {
+                console.debug('found something true');
+                console.debug(
+                    this.licenseList[i].fileUrl, ' is found');
+                return true;
+            }
         }
     }
     return false;
@@ -267,9 +269,9 @@ DomHandler.prototype.scriptHasJsWebLabel = function(script) {
 DomHandler.prototype.processScripts = function () {
     var that = this;
 
-    // check for the existence of the 
+    // check for the existence of the
     // js web labels first.
-    this.lookForJsWebLabels(function () { 
+    this.lookForJsWebLabels(function () {
 
         // gather and check all script elements on
         // page.
@@ -286,13 +288,14 @@ DomHandler.prototype.processScripts = function () {
  */
 DomHandler.prototype.checkAllScripts = function () {
     try {
-        console.debug('found in', this.pageURL, JSON.stringify(this.licenseList));
+        console.debug(
+            'found in', this.pageURL, JSON.stringify(this.licenseList));
         console.debug('checkAllScripts triggered async');
 
         // use domGatherer to gather scripts.
         this.domGatherer.findScripts();
         this.domGatherer.gatherScriptsContent();
-        this.domGatherer.gatherIntrinsecEvents();
+        this.domGatherer.gatherIntrinsicEvents();
 
         console.debug('fragment is', this.fragment);
 
@@ -324,7 +327,7 @@ DomHandler.prototype.checkAllScripts = function () {
 
 /**
  * lookForJsWebLabels
- * 
+ *
  * Checks if a link to a js web label table exists.
  * If it does, return an array of objects with the data
  * gathered (script name, path, license name, url, ...)
@@ -333,11 +336,11 @@ DomHandler.prototype.checkAllScripts = function () {
 DomHandler.prototype.lookForJsWebLabels = function (completed) {
     var that = this;
     console.debug("calling lookForJsWebLabels");
-    if (this.fragment != '#librejs=true') {
+    if (this.fragment !== '#librejs=true') {
         var webLabelFinder = new WebLabelFinder();
         webLabelFinder.init(
             this.dom,
-            this.pageURL, 
+            this.pageURL,
             function (licenseList) {
                 // assign array returned to property.
                 that.licenseList = licenseList;
@@ -349,24 +352,23 @@ DomHandler.prototype.lookForJsWebLabels = function (completed) {
     }
 };
 
-DomHandler.prototype.checkScriptForJsWebLabels = function (script) {
+DomHandler.prototype.checkScriptForJsWebLabels = function(script) {
     var scriptEntry;
 
     if (this.hasSrc(script) && this.scriptHasJsWebLabel(script)) {
-
-        // in the list of allowed scripts (through web labels)
-        scriptEntry = scriptObject.Script({'type': scriptTypes.EXTERNAL,
+        // This script is in the list of allowed scripts (through web labels)
+        scriptEntry = scriptObject.Script({
+            'type': scriptTypes.EXTERNAL,
             'status': statusTypes.ACCEPTED,
-                    'element':script, 
-                    'url': urlHandler.resolve(this.pageURL, script.src)});
+            'element': script,
+            'url': urlHandler.resolve(this.pageURL, script.src)
+        });
 
         scriptEntry.tagAsAccepted(this.pageURL, reasons.FREE);
-
         return true;
     }
 };
 
-
 /**
  * hasSrc
  * Check the given script has an src attribute.
@@ -387,7 +389,6 @@ DomHandler.prototype.hasSrc = function(script) {
  *
  */
 DomHandler.prototype.removeScriptIfDependent = function (script) {
-
     var nonWindowProps = script.tree.relationChecker.nonWindowProperties;
 
     for (var entry in nonWindowProps) {
@@ -397,11 +398,10 @@ DomHandler.prototype.removeScriptIfDependent = function (script) {
             return true;
         }
     }
-
 };
 
 /**
- * removeGivenJs 
+ * removeGivenJs
  * Remove a single script from the DOM.
  * @param script Obj The script element to be removed from the
  * DOM.
@@ -413,12 +413,12 @@ DomHandler.prototype.removeGivenJs = function (script, reason, singleton, hash)
     console.debug("removing given js hash", hash);
 
     if (script.status != statusTypes.REJECTED &&
-            script.status != statusTypes.JSWEBLABEL
-    ) {
+        script.status != statusTypes.JSWEBLABEL
+       ) {
         console.debug('removing a', script.type);
         if (script.type === scriptTypes.ATTRIBUTE &&
-                !isAllowed
-        ) {
+            !isAllowed
+           ) {
             this.removeGivenAttribute(script, reason);
             return;
         }
@@ -429,7 +429,8 @@ DomHandler.prototype.removeGivenJs = function (script, reason, singleton, hash)
             console.debug('removeGivenJs hash is', hash);
             script.tagAsRemoved(this.pageURL, reason, hash);
         } else {
-            script.element.setAttribute('data-librejs-dryrun', 'librejs/blocked');
+            script.element.setAttribute(
+                'data-librejs-dryrun', 'librejs/blocked');
             script.tagAsDryRun(this.pageURL, reason, hash);
         }
 
@@ -440,10 +441,13 @@ DomHandler.prototype.removeGivenJs = function (script, reason, singleton, hash)
 
         // remove src if dry run off.
         if (script.element.getAttribute('src') !== undefined) {
-            script.element.setAttribute('data-librejs-blocked-src', script.element.getAttribute('src'));
+            script.element.setAttribute(
+                'data-librejs-blocked-src',
+                script.element.getAttribute('src')
+            );
             if (!isAllowed) {
                 script.element.removeAttribute('src');
-            } 
+            }
         }
         if (isAllowed) {
             comment_str = 'LibreJS: Script should be blocked, but page is whitelisted.';
@@ -463,11 +467,11 @@ DomHandler.prototype.removeGivenJs = function (script, reason, singleton, hash)
 
 DomHandler.prototype.removeGivenAttribute = function (script, reason) {
     var i = 0,
-    le = script.jsAttributes.length;
+        le = script.jsAttributes.length;
 
     console.debug('removing given attribute', script, reason);
-    script.element.setAttribute('data-librejs-blocked-event', 
-            JSON.stringify(script.jsAttributes));
+    script.element.setAttribute('data-librejs-blocked-event',
+                                JSON.stringify(script.jsAttributes));
 
     script.tagAsRemoved(this.pageURL, reason, script.hash || script.tree.hash);
 
@@ -478,7 +482,7 @@ DomHandler.prototype.removeGivenAttribute = function (script, reason) {
         // only run if not in dry run mode.
         for (; i < le; i++) {
             console.debug('removing attribute', JSON.stringify(script.jsAttributes));
-            script.element.removeAttribute(script.jsAttributes[i].attribute);	      
+            script.element.removeAttribute(script.jsAttributes[i].attribute);
         }
     } else {
 
@@ -503,9 +507,14 @@ DomHandler.prototype.removeAllJs = function (reason) {
 
     try {
         this.removeAllArray(this.scripts, reason);
-        this.callback(this.dom);	    
+        this.callback(this.dom);
     } catch (x) {
-        console.debug('in removeAllJs method: ', x, 'number of scripts is', this.numScripts);
+        console.debug(
+            'in removeAllJs method: ',
+            x,
+            'number of scripts is',
+            this.numScripts
+        );
         this.callback(this.dom);
     }
 
@@ -521,9 +530,10 @@ DomHandler.prototype.removeAllArray = function(scriptArray, reason) {
         for (; i < le; i++) {
             script = scriptArray[i];
             if (script.type === scriptTypes.INLINE ||
-                    script.type === scriptTypes.EXTERNAL) {
-                        this.removeGivenJs(script, reason);
-                    } 
+                script.type === scriptTypes.EXTERNAL
+               ) {
+                this.removeGivenJs(script, reason);
+            }
             else if (script.type === scriptTypes.ATTRIBUTE) {
                 this.removeGivenAttribute(script, reason);
             }
@@ -544,7 +554,7 @@ exports.DomHandler = DomHandler;
  * @param callback function callback when all the work has been performed.
  */
 exports.domHandler = function(
-        dom, pageURL, fragment, responseStatus, callback) {
+    dom, pageURL, fragment, responseStatus, callback) {
     console.debug("Creating domHandler");
     var domHandler = new DomHandler();
     domHandler.init(dom, pageURL, fragment, responseStatus, callback);
