@@ -30,7 +30,7 @@ const statusTypes = scriptProperties.statusTypes;
 var jsInAttrRe = /javascript:/ig;
 
 // the list of all available event attributes
-var intrinsecEvents = [
+var intrinsicEvents = [
   "onload",
   "onunload",
   "onclick",
@@ -51,7 +51,7 @@ var intrinsecEvents = [
   "onchange"]; 
 
 exports.jsInAttrRe = jsInAttrRe;
-exports.intrinsecEvents = intrinsecEvents;
+exports.intrinsicEvents = intrinsicEvents;
 
 
 /**
@@ -102,18 +102,18 @@ exports.findJSinAttribute = function (elem, callback) {
  */
 exports.findOnJSAttribute = function (elem, callback) {
 
-  var i = 0, eventsLen = intrinsecEvents.length;
+  var i = 0, eventsLen = intrinsicEvents.length;
 
   var attribPairs = [];
 
   for (; i < eventsLen; i++) {
 
 	  // looping through all on* attributes
-	  if (elem.hasAttribute(intrinsecEvents[i])) {
+	  if (elem.hasAttribute(intrinsicEvents[i])) {
 
 	    attribPairs.push({
-            attribute: intrinsecEvents[i],
-            value: elem.getAttribute(intrinsecEvents[i])
+            attribute: intrinsicEvents[i],
+            value: elem.getAttribute(intrinsicEvents[i])
         });
 
 	  }
