@@ -35,7 +35,7 @@ var attributeHelpers = require("html_script_finder/dom_handler/attributes");
 var jsInAttrRe = attributeHelpers.jsInAttrRe;
 
 // the list of all available event attributes
-var intrinsecEvents = attributeHelpers.intrinsecEvents;
+var intrinsicEvents = attributeHelpers.intrinsicEvents;
 
 var privacyChecker = require("js_checker/privacy_checker").privacyCheck;
 
@@ -132,14 +132,14 @@ DomGatherer.prototype.findScripts = function() {
 };
 
 /**
- * gatherIntrinsecEvents
+ * gatherIntrinsicEvents
  *
  * Fetches all the event attributes that might contain JavaScript
  * as well as all element attributes that start with
  * "javascript:".
  *
  */
-DomGatherer.prototype.gatherIntrinsecEvents = function() {
+DomGatherer.prototype.gatherIntrinsicEvents = function() {
     var i = 0, j, k,
     all = this.d.dom.getElementsByTagName('*'),
     max = all.length,
