@@ -68,10 +68,15 @@ exports.getLicenseList = function (document) {
                     jsList.push({
                         'fileName': fileCell.textContent,
                         'fileUrl': fileCell.href,
-                        'fileHash': null, // we'll fill this with value when needed to compare script.
+
+                        // we'll fill this with value when needed to compare
+                        // script.
+                        'fileHash': null,
 
                         'licenseName': licenseCell.textContent,
-                        'licenseUrl': licenseCell.href, // this will now be a magnet link, most likely.
+
+                        // this will now be a magnet link, most likely.
+                        'licenseUrl': licenseCell.href,
 
                         'sourceName': sourceCell.textContent,
                         'sourceUrl': sourceCell.href
