@@ -37,17 +37,17 @@ var httpRequestObserver = {
         console.debug('atopic is', aTopic);
         var url, newListener, status;
 
-        if (aTopic == "http-on-examine-response" ||
-            aTopic == "http-on-examine-cached-response" ||
-            aTopic == "http-on-examine-merged-response"
+        if (aTopic === "http-on-examine-response" ||
+            aTopic === "http-on-examine-cached-response" ||
+            aTopic === "http-on-examine-merged-response"
         ) {
             request.QueryInterface(Ci.nsIHttpChannel);
 
-            if (request.URI.scheme != 'chrome' && 
+            if (request.URI.scheme !== 'chrome' && 
                 (request.responseStatus < 300 || 
                  request.responseStatus > 399) &&
                 (targetMimeTypes.test(request.contentType) || 
-                 request.contentType == undefined) &&
+                 request.contentType === undefined) &&
                 (!urlTester.isWhitelisted(request.URI.spec) &&
                  !urlTester.isWhitelisted(request.originalURI.spec))
             ) {
