@@ -89,8 +89,9 @@ StreamListener.prototype.onStreamComplete = function onStreamComplete(
 StreamListener.prototype.onDetermineCharset = function onDetermineCharset(
         loader, context, data) {
     var match, regex;
-    if (loader.channel.contentCharset != undefined &&
-            loader.channel.contentCharset != "") {
+    if (loader.channel.contentCharset !== undefined &&
+        loader.channel.contentCharset !== ""
+       ) {
         return loader.channel.contentCharset;
     } else {
         match = getRegexForContentType(loader.channel.contentType).exec(data);
