@@ -20,7 +20,7 @@
 
 var {Cc, Ci, Cu, Cm, Cr} = require("chrome");
 
-var narcissusWorker = require("narcissus_parser/narcissus_worker")
+var narcissusWorker = require("parser/narcissus_worker")
     .narcissusWorker;
 
 const nonTrivialModule = require("js_checker/nontrivial_checker");
