@@ -1,7 +1,7 @@
 /**
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
- * Copyright (C) 2011, 2012 Loic J. Duros
+ * Copyright (C) 2011, 2012, 2013, 2014 Loic J. Duros
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,31 +18,27 @@
  *
  */
 
-var privacyThreatJs = require('js_checker/privacy_threat_definitions.js');
-var patternUtils = require('js_checker/pattern_utils').patternUtils;
+const privacyThreatJs = require('js_checker/privacy_threat_definitions.js');
+const patternUtils = require('js_checker/pattern_utils').patternUtils;
 
 exports.privacyCheck = {
-  
-  checkScriptPrivacyThreat: function (currentScript) {
-	  var list = privacyThreatJs.js,
-	      i,
-	      jsRegexp,
-        match,
-	      max,
-	      check;
-	  
-	  currentScript = patternUtils.removeWhitespace(currentScript);
+    checkScriptPrivacyThreat: function (currentScript) {
+        var list = privacyThreatJs.js;
+        var i;
+        var item;
+        var max;
 
-	  for (item in list) {
-	    max = list[item].length;
+        currentScript = patternUtils.removeWhitespace(currentScript);
 
-	    for (i = 0; i < max; i++) {
-		    if (list[item][i].test(currentScript)) {
-		      return true;
-		    }
-	    }
+        for (item in list) {
+            max = list[item].length;
 
-	  }
-  }
-  
+            for (i = 0; i < max; i++) {
+                if (list[item][i].test(currentScript)) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    }
 };
