@@ -19,6 +19,9 @@
  */
 var relationCheckerObj = require("js_checker/relation_checker").relationChecker;
 
+// import free_libraries to populate the cache hash map.
+var free_libraries = require("script_entries/free_libraries");
+
 var crypto = require('script_entries/crypto');
 //const librejsStorage = require("settings/storage").librejsStorage;
 const checkTypes = require("js_checker/constant_types").checkTypes;
@@ -177,6 +180,4 @@ ScriptsCached.prototype.bulkImportCache = function(data) {
     console.debug("It looks like ", JSON.stringify(cachedResults));
 };
 
-// import free_libraries to populate the cache hash map.
-//var free_libraries = require("script_entries/free_libraries");
 exports.scriptsCached = new ScriptsCached();
