@@ -28,7 +28,10 @@ let settings_tab = require('settings/settings_tab');
 let allowedRef = require("http_observer/allowed_referrers").allowedReferrers;
 let urlHandler = require("url_handler/url_handler");
 let removedScripts = require("script_entries/removed_scripts").removedScripts;
-let acceptedScripts = require("script_entries/accepted_scripts").acceptedScripts;
+let acceptedScripts = require("script_entries/accepted_scripts")
+    .acceptedScripts;
+let jsLabelsPagesVisited = require('html_script_finder/web_labels/js_web_labels')
+    .jsLabelsPagesVisited;
 let dryRunScripts = require("script_entries/dryrun_scripts").dryRunScripts;
 let types = require("js_checker/constant_types");
 
@@ -39,6 +42,11 @@ function generateDataURI (encodedText) {
     return "data:text/html;charset=UTF-8;base64," + encodedText;
 }
 
+/**
+ * UI
+ *
+ * A singleton that starts the user interface content scripts.
+ */
 let UI = exports.UI = {
     init: function() {
         var mainPanel = panel.Panel({
@@ -89,7 +97,6 @@ let UI = exports.UI = {
             console.debug("hash is", hash);
             url = urlHandler.removeFragment(url);
             /*  var cached_result = scriptsCached.isCached(hash);
-                console.debug("cached_result is", cached_result);
                 if (cached_results) {
                 reason = cached_result['reason'];
                 }*/
@@ -128,8 +135,8 @@ let UI = exports.UI = {
 
         var menuitem = require("menuitems").Menuitem({
             id: 'librejs_settings',
-            menuid: "menu_ToolsPopup",
-            label: "LibreJS",
+            menuid: 'menu_ToolsPopup',
+            label: 'LibreJS Whitelist',
             onCommand: function() {
                 settings_tab.settingsManager.open();
             },
@@ -157,6 +164,7 @@ let UI = exports.UI = {
 
                 if (respData.event === 'scriptsFetched') {
                     var scriptsData = {
+                        'jsLabelsPagesVisited': jsLabelsPagesVisited,
                         'removed': removedScripts.getScripts(url),
                         'accepted': acceptedScripts.getScripts(url),
                         'dryRun': dryRunScripts.getScripts(url)
@@ -170,7 +178,6 @@ let UI = exports.UI = {
                 } else {
                     that.postMessage(respData);
                 }
-
             }
         });
     }
