@@ -21,7 +21,7 @@
 var main = require('main');
 var tabs = require('sdk/tabs');
 
-exports.testBug = function (assert, done) {
+/*exports.testBug = function (assert, done) {
     var tab = tabs.open('http://www.yahoo.com');
     //var tab2 = tabs.open('about:home');
     //tab.activate();
@@ -39,6 +39,6 @@ exports.testBug = function (assert, done) {
             //tab.close();
         }
     });
-};
+};*/
 
 //require('sdk/test').run(exports);
