@@ -1,7 +1,7 @@
 /**
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
- * Copyright (C) 2011, 2012 Loic J. Duros
+ * Copyright (C) 2011, 2012, 2014 Loic J. Duros
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,39 +18,43 @@
  *
  */
 
-var pageMod = require("page-mod");
+/*
+ * FIXME: This test relies on the cors-test2.html file (visible in bzr
+ * history), which in turn relies on an external PHP script that isn't around
+ * anymore. Because of this, I'm commenting out this test for now.
+ */
+
+/*
+var pageMod = require("sdk/page-mod");
 var tabs = require("sdk/tabs");
 var data = require("sdk/self").data;
-var timer = require("timer");
+
 exports.testCORS = function (test) { 
     test.waitUntilDone();
-        
+
     var mod = pageMod.PageMod({
-	include: /.*cors-test2.html/,
-	contentScriptWhen: 'end',
+        include: /.*cors-test2.html/,
+        contentScriptWhen: 'end',
 
-	contentScript: "window.setTimeout(function () { " + 
+        contentScript: "window.setTimeout(function () { " + 
             "var content = document.getElementById(\"cross\").innerHTML;" + 
-            "if (/snippet/.test(content)) {"
-            + "self.postMessage(\"Done!\");} "
-            + "}, 5000); ",
-
-	onAttach: function (worker) {
-
-	    worker.on('message', function (message) {
+            "if (/snippet/.test(content)) {" +
+            "self.postMessage(\"Done!\");} " +
+            "}, 5000); ",
 
+        onAttach: function (worker) {
+            worker.on('message', function (message) {
                 console.log("CORS bug test page fully loaded");
 
-		if (message === 'Done!') {
-                            test.assertEqual(true, true);
-		            test.done();
-		            mod.destroy();
-		}
-	    });
-	}
-
+                if (message === 'Done!') {
+                    test.assertEqual(true, true);
+                    test.done();
+                    mod.destroy();
+                }
+            });
+        }
     });
 
     tabs.open(data.url("test/cors-test2.html"));
-    
-};
\ No newline at end of file
+};
+*/
