@@ -1,7 +1,7 @@
 /**
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
- * Copyright (C) 2011, 2012 Loic J. Duros
+ * Copyright (C) 2011, 2012, 2014 Loic J. Duros
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +18,10 @@
  *
  */
 
-
-
 // these tests require Firefox 11 or later
 // using following command to run after placing nightly is /usr/local/: 
 // cfx --binary=/usr/local/bin/firefox-nightly test -f domHandler
 
-
 var domHandler = require("html_script_finder/dom_handler");
 var mockDom = require("./mock/mock_dom");
 
@@ -32,34 +29,43 @@ var mockDom = require("./mock/mock_dom");
 // access private objects from module.
 //var privateScope = loader.findSandboxForModule("html_script_finder/dom_handler").globalScope;
 
-
-
-exports.testAcceptedScriptAttribute = function (test) {
-    test.waitUntilDone();
-
+exports.testAcceptedScriptAttribute = function (assert, done) {
     var document = mockDom.acceptedScriptsDocument();
-    domHandler.domHandler (document, 
-			   'http://example.org/test.html',
-			   null,
-			   null,
-			   function (dom) {
-			       test.assertEqual(document.getElementsByTagName('script')[0].getAttribute('data-librejs'), 'accepted');
-			       test.assertEqual(document.getElementsByTagName('script')[1].getAttribute('data-librejs'), 'accepted');
-			       test.done();
-			   });
+    domHandler.domHandler(
+        document, 
+        'http://example.org/test.html',
+        null,
+        null,
+        function (dom) {
+            assert.equal(
+                document.getElementsByTagName('script')[0]
+                    .getAttribute('data-librejs'),
+                'accepted');
+            assert.equal(
+                document.getElementsByTagName('script')[1]
+                    .getAttribute('data-librejs'),
+                'accepted');
+            done();
+        }
+    );
 };
 
-exports.testDomWithOnAttrib = function (test) {
-    test.waitUntilDone();
+exports.testDomWithOnAttrib = function (assert, done) {
     var document = mockDom.domWithOnAttrib();
 
-    domHandler.domHandler (document,
-			   'http://example.org/test.html',
-			   null,
-			   null,
-			  function (dom) {
-			      test.assertEqual(document.getElementsByTagName('body')[0].getAttribute('data-librejs'), 'accepted');
-			      test.done();
-			  });
-
+    domHandler.domHandler (
+        document,
+        'http://example.org/test.html',
+        null,
+        null,
+        function (dom) {
+            assert.equal(
+                document.getElementsByTagName('body')[0]
+                    .getAttribute('data-librejs'),
+                'accepted');
+            done();
+        }
+    );
 };
+
+require('sdk/test').run(exports);
