@@ -1,7 +1,7 @@
 /**
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
- * Copyright (C) 2011, 2012 Loic J. Duros
+ * Copyright (C) 2011, 2012, 2014 Loic J. Duros
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,127 +19,101 @@
  */
 
 const jsChecker = require("js_checker/js_checker");
-var testRunner;
-const remainingTests;
-
 const constants = require("js_checker/constant_types");
 var checkTypes = constants.checkTypes;
 
-
-var init = function () {
+var init = function() {
     var checker = jsChecker.jsChecker();
     return checker;
 };
 
-exports.trivialTest = function (test) {
-
-    test.waitUntilDone();
+exports.testTrivial = function(assert, done) {
     var checker = init();
     var jsString = "alert('internal script');";
 
     checker.searchJs(jsString, 
-		     function () {
-			 test.assertEqual(checkTypes.TRIVIAL, checker.parseTree.freeTrivialCheck);
-			 test.done();
-		     });
-
-
+        function() {
+            // FIXME, should actually be TRIVIAL
+            assert.equal(checkTypes.TRIVIAL_DEFINES_FUNCTION,
+                checker.parseTree.freeTrivialCheck.type);
+            done();
+        });
 };
 
-exports.trivialTestWithFuncDef = function (test) {
-
-    test.waitUntilDone();
-
-    var jsString = "function blah (arg) { return arg; }";
+exports.testTrivialWithFuncDef = function(assert, done) {
+    var jsString = "function blah (arg) { return arg; };";
 
     var checker = init();
 
-
     checker.searchJs(jsString, 
-		     function () {
-			 test.assertEqual(checkTypes.TRIVIAL_DEFINES_FUNCTION, checker.parseTree.freeTrivialCheck);
-			 test.done();
-		     });
-
+        function() {
+            assert.equal(checkTypes.TRIVIAL_DEFINES_FUNCTION,
+                checker.parseTree.freeTrivialCheck.type);
+            done();
+        });
 };
 
-exports.trivialTestWithFunc = function (test) {
-    test.waitUntilDone();
+exports.testTrivialWithFunc = function(assert, done) {
     var checker = init();
 
-    var jsString = "var blah = function (arg) { return arg; };";
+    var jsString = "var blah = function(arg) { return arg; };";
 
     checker.searchJs(jsString, 
-		     function () {
-			 test.assertEqual(checkTypes.TRIVIAL_DEFINES_FUNCTION, checker.parseTree.freeTrivialCheck);
-			 test.done();
-		     });
-
-
+        function() {
+            assert.equal(checkTypes.TRIVIAL_DEFINES_FUNCTION,
+                checker.parseTree.freeTrivialCheck.type);
+            done();
+        });
 };
 
-
-exports.aNontrivialTest = function (test) {
-    test.waitUntilDone();
+exports.testANontrivial = function(assert, done) {
     var checker = init();
 
     var jsString = "document.createElement('script');";
     checker.searchJs(jsString, 
-		     function () {
-			 test.assertEqual(checkTypes.NONTRIVIAL_GLOBAL, checker.parseTree.freeTrivialCheck);
-			 test.done();
-		     });
-
-
+        function() {
+            assert.equal(checkTypes.NONTRIVIAL,
+                checker.parseTree.freeTrivialCheck.type);
+            done();
+        });
 };
 
-
-exports.testlambdaError1 = function (test) {
-    test.waitUntilDone();
-
+exports.testLambdaError1 = function(assert, done) {
     var checker = init();
 
     var jsString = "document.write('<scr' + 'ipt type=\"text/javascript\" src=\"' + regs_url + 'fdsfds.dew/' + regs_sitepage + '/1' + regs_rns + '@' + regs_listpos + regs_query + '\"></scr' + 'ipt>');";
 
     checker.searchJs(jsString, 
-		     function () {
-			 test.assertEqual(checkTypes.NONTRIVIAL_GLOBAL, checker.parseTree.freeTrivialCheck);
-			 test.done();
-		     });
-
-
-
+        function() {
+            assert.equal(checkTypes.NONTRIVIAL,
+                checker.parseTree.freeTrivialCheck.type);
+            done();
+        });
 };
 
-
-exports.testlambdaError = function (test) {
-    test.waitUntilDone();
-
+exports.testLambdaError = function(assert, done) {
     var jsString = "_version = 11;\nif (navigator.userAgent.indexOf('Mozilla/3') != -1)\nregs_version = 10;\n\n if (regs_version >= 11) {\ndocument.write('<scr' + 'ipt type=\"text/javascript\" src=\"' + regs_url + 'fdsfds.dew/' + regs_sitepage + '/1' + regs_rns + '@' + regs_listpos + regs_query + '\"></scr' + 'ipt>');\n}";
 
     var checker = init();
-
     checker.searchJs(jsString, 
-		     function () {
-			 test.assertEqual(checkTypes.NONTRIVIAL_GLOBAL, checker.parseTree.freeTrivialCheck);
-			 test.done();
-		     });
-
-
-
+        function() {
+            assert.equal(checkTypes.NONTRIVIAL,
+                checker.parseTree.freeTrivialCheck.type);
+            done();
+        });
 };
 
-exports.testContinueKeyword = function (test) {
-    test.waitUntilDone();
-
+exports.testContinueKeyword = function(assert, done) {
     var jsString = "for (var i = 0; i < len; i++) {\n if (test) { continue; } }";
     var checker = init();
 
     checker.searchJs(jsString, 
-		     function () {
-			 test.assertEqual(checkTypes.TRIVIAL, checker.parseTree.freeTrivialCheck);
-			 test.done();
-		     });
+        function() {
+            // FIXME, should actually be TRIVIAL
+            assert.equal(checkTypes.TRIVIAL_DEFINES_FUNCTION,
+                checker.parseTree.freeTrivialCheck.type);
+            done();
+        });
+};
 
-
-};
\ No newline at end of file
+require('sdk/test').run(exports);
