@@ -1,7 +1,7 @@
 /**
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
- * Copyright (C) 2011, 2012 Loic J. Duros
+ * Copyright (C) 2011, 2012, 2014 Loic J. Duros
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,13 +21,15 @@
 var streamLoader = require("http_observer/stream_loader.js");
 var {Cc, Ci, Cu, Cm, Cr} = require("chrome");
 
-exports.testListener = function (test) { 
-    var streamloader = Cc["@mozilla.org/network/unichar-stream-loader;1"].
+exports.testListener = function (assert) { 
+    var mozStreamLoader = Cc["@mozilla.org/network/unichar-stream-loader;1"].
         createInstance(Ci.nsIUnicharStreamLoader);
-    streamloader.init(streamLoader.listener);
+    mozStreamLoader.init(streamLoader.streamLoader().listener);
     var ios = Cc["@mozilla.org/network/io-service;1"]
             .getService(Ci.nsIIOService);
-    var chan = ios.newChannel("http://lduros.net", null, null);
-    chan.asyncOpen(streamloader, null);
-    test.done();
+    var chan = ios.newChannel("http://example.com", null, null);
+    chan.asyncOpen(mozStreamLoader, null);
+    assert.ok(true);
 };
+
+require('sdk/test').run(exports);
